/****************************************Copyright (c)****************************************************
**                                      

**
**--------------File Info---------------------------------------------------------------------------------
** File name:               LWIP.c
** Descriptions:            None
**
**--------------------------------------------------------------------------------------------------------

**--------------------------------------------------------------------------------------------------------
** Modified by:             
** Modified date:           
** Version:                 
** Descriptions:            
**
*********************************************************************************************************/

/* Includes ------------------------------------------------------------------*/

#include "lwIP.h"
#include "lwIP/tcp.h"
#include "lwIP/udp.h"
#include "lwIP/dhcp.h"
#include "lwip/memp.h"
#include "ethernetif.h"
#include "lwIP/tcpip.h"
#include "netif/etharp.h"
#include "arch/sys_arch.h"
#include <includes.h>
/* Private define ------------------------------------------------------------*/
#define MAX_DHCP_TRIES        4
#define	MAX_X	             DISP_HOR_RESOLUTION
#define	MAX_Y	             DISP_VER_RESOLUTION

/* Private variables ---------------------------------------------------------*/
struct netif _netif;
static uint32_t IPaddress = 0;

/* Private function prototypes -----------------------------------------------*/
static void list_if                (void);
static void TcpipInitDone          (void *arg);


/*******************************************************************************
* Function Name  : list_if
* Description    : display ip address in serial port debug windows
* Input          : None
* Output         : None
* Return         : None
* Attention		 : None
*******************************************************************************/
static void list_if(void)
{
    printf("Default network interface: %c%c \r\n", _netif.name[0], _netif.name[1]);
    printf("ip address: %s \r\n", inet_ntoa(*((struct in_addr*)&(_netif.ip_addr))));
    printf("gw address: %s \r\n", inet_ntoa(*((struct in_addr*)&(_netif.gw))));
    printf("net mask  : %s \r\n", inet_ntoa(*((struct in_addr*)&(_netif.netmask))));
}

/*******************************************************************************
* Function Name  : TcpipInitDone
* Description    : TcpipInitDone wait for tcpip init being done
* Input          : - arg: the semaphore to be signaled
* Output         : None
* Return         : None
* Attention		 : None
*******************************************************************************/
static void TcpipInitDone(void *arg)
{
    sys_sem_t *sem;
    sem = arg;
    sys_sem_signal(*sem);
}

/*******************************************************************************
* Function Name  : Init_lwIP
* Description    : Init_lwIP initialize the LwIP
* Input          : None
* Output         : None
* Return         : None
* Attention		 : None
*******************************************************************************/
void Init_lwIP(void)
{
    struct ip_addr ipaddr;
    struct ip_addr netmask;
    struct ip_addr gw;

    sys_sem_t sem;
    
    sys_init();
    
    /* Initializes the dynamic memory heap defined by MEM_SIZE.*/
    mem_init();
    
    /* Initializes the memory pools defined by MEMP_NUM_x.*/
    memp_init();
    
    pbuf_init();	
    netif_init();
    


    printf("TCP/IP initializing... \r\n");
    sem = sys_sem_new(0);
    tcpip_init(TcpipInitDone, &sem);
    sys_sem_wait(sem);
    sys_sem_free(sem);
    printf("TCP/IP initialized. \r\n");
      
#if LWIP_DHCP
    /* DHCP */
    ipaddr.addr = 0;
    netmask.addr = 0;
    gw.addr = 0;
#else
    /* þ̬IP */
    IP4_ADDR(&ipaddr, emacIPADDR0, emacIPADDR1, emacIPADDR2, emacIPADDR3 );
    IP4_ADDR(&netmask,emacNET_MASK0, emacNET_MASK1, emacNET_MASK2, emacNET_MASK3 );
    IP4_ADDR(&gw, emacGATEWAY_ADDR0, emacGATEWAY_ADDR1, emacGATEWAY_ADDR2, emacGATEWAY_ADDR3 );
#endif
    
    netif_add(&_netif, &ipaddr, &netmask, &gw, NULL, &ethernetif_init, &tcpip_input);
    netif_set_default(&_netif);
    
#if LWIP_DHCP
    dhcp_start(&_netif);
#endif
  netif_set_up(&_netif);

	list_if();
}

/*******************************************************************************
* Function Name  : Display_IPAddress
* Description    : Display_IPAddress Display IP Address
* Input          : None
* Output         : None
* Return         : None
* Attention		 : None
*******************************************************************************/
void Display_IPAddress(void)
{
    if(IPaddress != _netif.ip_addr.addr)
    {   
	    /* IP ַı*/
        __IO uint8_t iptab[4];
        uint8_t iptxt[20];
        
        /* read the new IP address */
        IPaddress = _netif.ip_addr.addr;
        
        iptab[0] = (uint8_t)(IPaddress >> 24);
        iptab[1] = (uint8_t)(IPaddress >> 16);
        iptab[2] = (uint8_t)(IPaddress >> 8);
        iptab[3] = (uint8_t)(IPaddress);
        
        sprintf((char*)iptxt, "   %d.%d.%d.%d    ", iptab[3], iptab[2], iptab[1], iptab[0]);
                
        /* Display the new IP address */
#if LWIP_DHCP
        if(netif.flags & NETIF_FLAG_DHCP)
        {   
		    /* IPַDHCPָ */
            /* Display the IP address */
						printf("IP ַDHCPָ\n");
        }
        else
#endif  
        /* ̬IPַ */
        {   
		    /* Display the IP address */
		       	printf("ֹIPַ\n");

        }
    }
#if LWIP_DHCP
    else if(IPaddress == 0)
    {   
	    /* ȴDHCPIP */
		   printf("ȴIP \n");
        
        /* If no response from a DHCP server for MAX_DHCP_TRIES times */
        /* stop the dhcp client and set a static IP address */
        if(netif.dhcp->tries > MAX_DHCP_TRIES) 
        {   
		    /* DHCPԴþ̬IP */
            struct ip_addr ipaddr;
            struct ip_addr netmask;
            struct ip_addr gw;
            
		        printf("DHCPԴ\n");

            dhcp_stop(&netif);
            
            IP4_ADDR(&ipaddr, emacIPADDR0, emacIPADDR1, emacIPADDR2, emacIPADDR3 );
            IP4_ADDR(&netmask,emacNET_MASK0, emacNET_MASK1, emacNET_MASK2, emacNET_MASK3 );
            IP4_ADDR(&gw, emacGATEWAY_ADDR0, emacGATEWAY_ADDR1, emacGATEWAY_ADDR2, emacGATEWAY_ADDR3 );
            
            netif_set_addr(&netif, &ipaddr , &netmask, &gw);
            
            list_if();
        }
    }
#endif
}



/*********************************************************************************************************
      END FILE
*********************************************************************************************************/

